@@ -3,7 +3,7 @@
  *  BlueZ - Bluetooth protocol stack for Linux
  *
  *  Copyright (C) 2006-2007  Nokia Corporation
- *  Copyright (C) 2004-2008  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2004-2009  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This library is free software; you can redistribute it and/or
@@ -96,10 +96,10 @@ struct bluetooth_a2dp {
 	sbc_capabilities_t sbc_capabilities;
 	sbc_t sbc;				/* Codec data */
 	int sbc_initialized;			/* Keep track if the encoder is initialized */
-	int codesize;				/* SBC codesize */
+	unsigned int codesize;			/* SBC codesize */
 	int samples;				/* Number of encoded samples */
 	uint8_t buffer[BUFFER_SIZE];		/* Codec transfer buffer */
-	int count;				/* Codec transfer buffer counter */
+	unsigned int count;			/* Codec transfer buffer counter */
 
 	int nsamples;				/* Cumulative number of codec samples */
 	uint16_t seq_num;			/* Cumulative packet sequence */
@@ -131,11 +131,11 @@ struct bluetooth_data {
 	struct bluetooth_alsa_config alsa_config;	/* ALSA resource file parameters */
 	volatile snd_pcm_sframes_t hw_ptr;
 	int transport;					/* chosen transport SCO or AD2P */
-	int link_mtu;					/* MTU for selected transport channel */
+	unsigned int link_mtu;				/* MTU for selected transport channel */
 	volatile struct pollfd stream;			/* Audio stream filedescriptor */
 	struct pollfd server;				/* Audio daemon filedescriptor */
 	uint8_t buffer[BUFFER_SIZE];		/* Encoded transfer buffer */
-	int count;					/* Transfer buffer counter */
+	unsigned int count;				/* Transfer buffer counter */
 	struct bluetooth_a2dp a2dp;			/* A2DP data */
 
 	pthread_t hw_thread;				/* Makes virtual hw pointer move */
@@ -224,7 +224,7 @@ static void *playback_hw_thread(void *param)
 
 			/* Reset point of reference to avoid too big values
 			 * that wont fit an unsigned int */
-			if (delta.tv_sec < UINT_SECS_MAX)
+			if ((unsigned int) delta.tv_sec < UINT_SECS_MAX)
 				prev_periods = periods;
 			else {
 				prev_periods = 0;
@@ -797,8 +797,7 @@ static int bluetooth_playback_poll_revents(snd_pcm_ioplug_t *io,
 	if (pfds[1].revents & (POLLERR | POLLHUP | POLLNVAL))
 		io->state = SND_PCM_STATE_DISCONNECTED;
 
-	revents[0] = (pfds[0].revents & ~POLLIN) | POLLOUT;
-	revents[1] = (pfds[1].revents & ~POLLIN);
+	*revents = (pfds[0].revents & POLLIN) ? POLLOUT : 0;
 
 	return 0;
 }
@@ -812,7 +811,8 @@ static snd_pcm_sframes_t bluetooth_hsp_read(snd_pcm_ioplug_t *io,
 	struct bluetooth_data *data = io->private_data;
 	snd_pcm_uframes_t frames_to_write, ret;
 	unsigned char *buff;
-	int nrecv, frame_size = 0;
+	unsigned int frame_size = 0;
+	int nrecv;
 
 	DBG("areas->step=%u areas->first=%u offset=%lu size=%lu io->nonblock=%u",
 			areas->step, areas->first, offset, size, io->nonblock);
@@ -823,14 +823,14 @@ static snd_pcm_sframes_t bluetooth_hsp_read(snd_pcm_ioplug_t *io,
 		goto proceed;
 
 	nrecv = recv(data->stream.fd, data->buffer, data->link_mtu,
-			MSG_WAITALL | (io->nonblock ? MSG_DONTWAIT : 0));
+					io->nonblock ? MSG_DONTWAIT : 0);
 
 	if (nrecv < 0) {
 		ret = (errno == EPIPE) ? -EIO : -errno;
 		goto done;
 	}
 
-	if (nrecv != data->link_mtu) {
+	if ((unsigned int) nrecv != data->link_mtu) {
 		ret = -EIO;
 		SNDERR(strerror(-ret));
 		goto done;
@@ -969,7 +969,8 @@ static snd_pcm_sframes_t bluetooth_a2dp_write(snd_pcm_ioplug_t *io,
 	struct bluetooth_data *data = io->private_data;
 	struct bluetooth_a2dp *a2dp = &data->a2dp;
 	snd_pcm_sframes_t ret = 0;
-	int frame_size, encoded, written, bytes_left;
+	unsigned int bytes_left;
+	int frame_size, encoded, written;
 	uint8_t *buff;
 
 	DBG("areas->step=%u areas->first=%u offset=%lu size=%lu",
@@ -1182,7 +1183,7 @@ static int bluetooth_hsp_hw_constraint(snd_pcm_ioplug_t *io)
 		SND_PCM_ACCESS_MMAP_INTERLEAVED
 	};
 	unsigned int format_list[] = {
-		SND_PCM_FORMAT_S16_LE
+		SND_PCM_FORMAT_S16
 	};
 	int err;
 
@@ -1237,7 +1238,7 @@ static int bluetooth_a2dp_hw_constraint(snd_pcm_ioplug_t *io)
 		SND_PCM_ACCESS_MMAP_INTERLEAVED
 	};
 	unsigned int format_list[] = {
-		SND_PCM_FORMAT_S16_LE
+		SND_PCM_FORMAT_S16
 	};
 	unsigned int rate_list[4];
 	unsigned int rate_count;
@@ -1495,7 +1496,8 @@ static int audioservice_send(int sk, const bt_audio_msg_header_t *msg)
 
 	length = msg->length ? msg->length : BT_SUGGESTED_BUFFER_SIZE;
 
-	DBG("sending %s", bt_audio_strmsg(msg->msg_type));
+	DBG("sending %s:%s", bt_audio_strtype(msg->type),
+		bt_audio_strname(msg->name));
 	if (send(sk, msg, length, 0) > 0)
 		err = 0;
 	else {
@@ -1668,6 +1670,8 @@ failed:
 	return err;
 }
 
+SND_PCM_PLUGIN_DEFINE_FUNC(bluetooth);
+
 SND_PCM_PLUGIN_DEFINE_FUNC(bluetooth)
 {
 	struct bluetooth_data *data;
